<?php
  /* vim: set expandtab tabstop=4 softtabstop=4 shiftwidth=4:
  Codificación: UTF-8
  +----------------------------------------------------------------------+
  | Elastix version 2.3.0-12                                               |
  | http://www.elastix.org                                               |
  +----------------------------------------------------------------------+
  | Copyright (c) 2006 Palosanto Solutions S. A.                         |
  +----------------------------------------------------------------------+
  | Cdla. Nueva Kennedy Calle E 222 y 9na. Este                          |
  | Telfs. 2283-268, 2294-440, 2284-356                                  |
  | Guayaquil - Ecuador                                                  |
  | http://www.palosanto.com                                             |
  +----------------------------------------------------------------------+
  | The contents of this file are subject to the General Public License  |
  | (GPL) Version 2 (the "License"); you may not use this file except in |
  | compliance with the License. You may obtain a copy of the License at |
  | http://www.opensource.org/licenses/gpl-license.php                   |
  |                                                                      |
  | Software distributed under the License is distributed on an "AS IS"  |
  | basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See  |
  | the License for the specific language governing rights and           |
  | limitations under the License.                                       |
  +----------------------------------------------------------------------+
  | The Original Code is: Elastix Open Source.                           |
  | The Initial Developer of the Original Code is PaloSanto Solutions    |
  +----------------------------------------------------------------------+
  $Id: paloSantoSmartassistant.class.php,v 1.1 2014-01-20 07:01:33 Alberto Santos asantos@palosanto.com Exp $ */
class paloSantoSmartassistant{
    var $_DB;
    var $errMsg;

    function paloSantoSmartassistant(&$pDB)
    {
        // Se recibe como parámetro una referencia a una conexión paloDB
        if (is_object($pDB)) {
            $this->_DB =& $pDB;
            $this->errMsg = $this->_DB->errMsg;
        } else {
            $dsn = (string)$pDB;
            $this->_DB = new paloDB($dsn);

            if (!$this->_DB->connStatus) {
                $this->errMsg = $this->_DB->errMsg;
                // debo llenar alguna variable de error
            } else {
                // debo llenar alguna variable de error
            }
        }
    }

    function getTotalDevices($filter_field, $filter_value)
    {
	$arrOptions = array("usuario","extension","target");
        $where    = "";
        $arrParam = null;
        if(isset($filter_field) & $filter_field !=""){
	    if(!in_array($filter_field,$arrOptions))
		$filter_field = "usuario";
            $where    = "where $filter_field like ?";
            $arrParam = array("%$filter_value%");
        }

        $query   = "SELECT COUNT(*) FROM user_device $where";

        $result=$this->_DB->getFirstRowQuery($query, false, $arrParam);

        if($result===FALSE){
            $this->errMsg = $this->_DB->errMsg;
            return FALSE;
        }
        return $result[0];
    }

    function getDevices($limit, $offset, $filter_field, $filter_value)
    {
	$arrOptions = array("usuario","extension","target");
        $where    = "";
        $arrParam = null;
        if(isset($filter_field) & $filter_field !=""){
	    if(!in_array($filter_field,$arrOptions))
                $filter_field = "usuario";
            $where    = "where $filter_field like ?";
            $arrParam = array("%$filter_value%");
        }

        $query   = "SELECT * FROM user_device $where LIMIT $limit OFFSET $offset";

        $result=$this->_DB->fetchTable($query, true, $arrParam);

        if($result==FALSE){
            $this->errMsg = $this->_DB->errMsg;
            return array();
        }
        return $result;
    }

    function getDeviceByID($id)
    {
        $query = "SELECT * FROM user_device WHERE usuario=?";

        $result=$this->_DB->getFirstRowQuery($query, true, array("$id"));

        if($result===FALSE){
            $this->errMsg = $this->_DB->errMsg;
            return array();
        }
        return $result;
    }

    function getExtensions($deviceID=NULL)
    {
	$dsn = generarDSNSistema("asteriskuser","asterisk");
	$pDB = new paloDB($dsn);
	$query = "SELECT extension FROM users ORDER BY extension";

	$result = $pDB->fetchTable($query,TRUE);
	if($result === FALSE)
		return array();
	else{
		$arrExtensions = array();
		foreach($result as $extension)
		     $arrExtensions[$extension["extension"]] = $extension["extension"];
		$sWhere = "";
		$params = NULL;
		if(isset($deviceID)){
			$sWhere = "WHERE usuario <> ?";
			$params = array($deviceID);
		}
		$query = "SELECT extension FROM user_device $sWhere";
		$result = $this->_DB->fetchTable($query,TRUE,$params);
		if($result === FALSE)
			return array();
		$arrExtensions_used = array();
		foreach($result as $extension_used)
		     $arrExtensions_used[$extension_used["extension"]] = $extension_used["extension"];
		return array_diff($arrExtensions,$arrExtensions_used);
	}
    }

    function editDevice($deviceID,$extension,$target)
    {
	$query = "UPDATE user_device set extension=?, target=? WHERE usuario=?";
    
        $result = $this->_DB->genQuery($query,array($extension,$target,$deviceID));
	if($result === FALSE){
		$this->errMsg = $this->_DB->errMsg;
		return FALSE;
	}
	return TRUE;
    }

    function saveDevice($deviceID,$extension,$target)
    {
	$query = "INSERT INTO user_device VALUES (?,?,'',?)";

	$result = $this->_DB->genQuery($query,array($deviceID,$extension,$target));
	if($result === FALSE){
                $this->errMsg = $this->_DB->errMsg;
                return FALSE;
        }
	$query = "INSERT INTO push_id (usuario,datetime) VALUES (?,now())";
	
	$result = $this->_DB->genQuery($query,array($deviceID));
	if($result === FALSE){
                $this->errMsg = $this->_DB->errMsg;
                return FALSE;
        }
	return TRUE;
    }

    function deleteDevice($deviceID)
    {	
	$query = "DELETE FROM user_device WHERE usuario=?";
	
	$result = $this->_DB->genQuery($query,array($deviceID));
	if($result === FALSE){
                $this->errMsg = $this->_DB->errMsg;
                return FALSE;
        }
	$query = "DELETE FROM auto_settings WHERE usuario=?";

	$result = $this->_DB->genQuery($query,array($deviceID));
	if($result === FALSE){
                $this->errMsg = $this->_DB->errMsg;
                return FALSE;
        }
	$query = "DELETE FROM cid_settings WHERE usuario=?";
    
        $result = $this->_DB->genQuery($query,array($deviceID));
        if($result === FALSE){
                $this->errMsg = $this->_DB->errMsg;
                return FALSE;
        }
	$query = "DELETE FROM incall WHERE usuario=?";
    
        $result = $this->_DB->genQuery($query,array($deviceID));
        if($result === FALSE){
                $this->errMsg = $this->_DB->errMsg;
                return FALSE;
        }
	$query = "DELETE FROM main_settings WHERE usuario=?";
    
        $result = $this->_DB->genQuery($query,array($deviceID));
        if($result === FALSE){
                $this->errMsg = $this->_DB->errMsg;
                return FALSE;
        }
	$query = "DELETE FROM push_id WHERE usuario=?";
    
        $result = $this->_DB->genQuery($query,array($deviceID));
        if($result === FALSE){
                $this->errMsg = $this->_DB->errMsg;
                return FALSE;
        }
	$query = "DELETE FROM target_settings WHERE usuario=?";
    
        $result = $this->_DB->genQuery($query,array($deviceID));
        if($result === FALSE){
                $this->errMsg = $this->_DB->errMsg;
                return FALSE;
        }
	return TRUE;
    }
}
